![test](https://github.com/davips/dupy/workflows/test/badge.svg)
[![codecov](https://codecov.io/gh/davips/dupy/branch/main/graph/badge.svg)](https://codecov.io/gh/davips/dupy)

# dupy
Find duplicate folders

### Install
```bash
pip install dupy
```

### Usage
```bash
dupy folder [max=100]
dupy folder1 folder2 folder3 ... [max=100]
```
